@@ -518,7 +518,7 @@ window.cockpit_po = {
  ],
  "Log in with your server user account.": [
   null,
-  "Přihlášení pomocí uživatelského účtu na tomto serveru."
+  "Přihlaste se pomocí uživatelského účtu na serveru."
  ],
  "Log messages": [
   null,
@@ -992,10 +992,6 @@ window.cockpit_po = {
   null,
   "Věž"
  ],
- "Transient packageless sessions require the same operating system and version, for compatibility reasons: $0.": [
-  null,
-  "Přechodná bezbalíčkové relace vyžadují stejný operační systém a jeho verzi (z důvodů kompatibility): $0."
- ],
  "Trust and add host": [
   null,
   "Důvěřovat a přidat hostitele"
@@ -1028,6 +1024,10 @@ window.cockpit_po = {
   null,
   "Neznámý hostitel: $0"
  ],
+ "Unsupported shell. Check the journal for details.": [
+  null,
+  "Nepodporovaný shell. Ohledně podrobností se podívejte do žurnálu."
+ ],
  "Untrusted host": [
   null,
   "Nedůvěryhodný stroj"
